==> WinBinder-0.32.108.tgz: Code/make_release/make.rc.php <==
<?php

// Control identifiers

if(!defined("IDD_DLG1001")) define("IDD_DLG1001", 1001);
if(!defined("IDC_RESULT")) define("IDC_RESULT", 1002);
if(!defined("IDC_VERSION")) define("IDC_VERSION", 1007);
if(!defined("IDC_TYPE")) define("IDC_TYPE", 1009);
if(!defined("IDC_VERBOSE")) define("IDC_VERBOSE", 1010);
if(!defined("IDC_STATIC1008")) define("IDC_STATIC1008", 1008);
if(!defined("IDC_NOTES")) define("IDC_NOTES", 1012);
if(!defined("IDC_GROUPBOX1014")) define("IDC_GROUPBOX1014", 1014);
if(!defined("IDC_CHM")) define("IDC_CHM", 1015);
if(!defined("IDC_COPYFILES")) define("IDC_COPYFILES", 1018);
if(!defined("IDC_EXPORTTODO")) define("IDC_EXPORTTODO", 1019);
if(!defined("IDC_CHECKDLLS")) define("IDC_CHECKDLLS", 1020);
if(!defined("IDC_TGZ")) define("IDC_TGZ", 1021);
if(!defined("IDC_ZIP")) define("IDC_ZIP", 1022);
if(!defined("IDC_RELNOTES")) define("IDC_RELNOTES", 1023);
if(!defined("IDC_GO")) define("IDC_GO", 1024);
if(!defined("IDC_ABOUT")) define("IDC_ABOUT", 1025);
if(!defined("IDC_SAVEINI")) define("IDC_SAVEINI", 1026);
if(!defined("IDC_GROUPBOX1027")) define("IDC_GROUPBOX1027", 1027);
if(!defined("IDC_STATIC1028")) define("IDC_STATIC1028", 1028);
if(!defined("IDC_STATIC1029")) define("IDC_STATIC1029", 1029);
if(!defined("IDC_MIME")) define("IDC_MIME", 1030);
if(!defined("IDC_FLIST")) define("IDC_FLIST", 1031);
if(!defined("IDC_XML")) define("IDC_XML", 1032);
if(!defined("IDC_STATIC1033")) define("IDC_STATIC1033", 1033);

// Create window

$mainwin = wb_create_window(NULL, PopupWindow, "Make releases", WBC_CENTER, WBC_CENTER, 561, 482, WBC_INVISIBLE, 0);

// Insert controls

wb_create_control($mainwin, Frame, "General Options", 10, 4, 262, 101, IDC_GROUPBOX1027, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Frame, "Build Options", 282, 4, 262, 227, IDC_GROUPBOX1014, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, EditBox, "(Output)", 10, 116, 262, 334, IDC_RESULT, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, Label, "Release &Number:", 19, 31, 92, 16, IDC_STATIC1008, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);
wb_create_control($mainwin, EditBox, "", 116, 27, 95, 21, IDC_VERSION, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "Release &Type:", 22, 60, 90, 16, IDC_STATIC1029, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);
wb_create_control($mainwin, ComboBox, "", 116, 55, 149, 98, IDC_TYPE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "&Verbose Output", 116, 80, 131, 21, IDC_VERBOSE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "Release notes:", 282, 237, 86, 16, IDC_STATIC1028, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, EditBox, "", 282, 259, 262, 155, IDC_NOTES, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, CheckBox, "Copy HTML &Files to Application Folder", 297, 21, 217, 21, IDC_COPYFILES, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Compile &CHM (HTML Help) Manual", 297, 41, 232, 21, IDC_CHM, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Export T&o Do List as an HTML file", 297, 60, 237, 21, IDC_EXPORTTODO, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Generate &Zip Archive", 297, 80, 125, 21, IDC_ZIP, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Check if WinBinder &DLLs are Up-to-Date", 321, 126, 217, 21, IDC_CHECKDLLS, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "From file list:", 312, 106, 70, 16, IDC_STATIC1033, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);
wb_create_control($mainwin, EditBox, "", 392, 103, 116, 19, IDC_FLIST, WBC_VISIBLE | WBC_ENABLED | WBC_READONLY);
wb_create_control($mainwin, CheckBox, "Create &XML Package Information (PECL)", 321, 145, 217, 21, IDC_XML, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Convert Zip to T&gz (PECL)", 321, 165, 197, 21, IDC_TGZ, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "&MIME Encode Zip file (for e-mail)", 321, 185, 191, 21, IDC_MIME, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Save &Release Notes", 297, 206, 152, 22, IDC_RELNOTES, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "Go", 282, 423, 77, 26, IDC_GO, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "&Save Config.", 374, 423, 77, 26, IDC_SAVEINI, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "&About...", 468, 423, 77, 26, IDC_ABOUT, WBC_VISIBLE | WBC_ENABLED);

// End controls

?>

==> WinBinder-0.33.113.tgz: Code/make_release/make.rc.php <==
<?php

// Control identifiers

if(!defined("IDD_DLG1001")) define("IDD_DLG1001", 1001);
if(!defined("IDC_RESULT")) define("IDC_RESULT", 1002);
if(!defined("IDC_VERSION")) define("IDC_VERSION", 1007);
if(!defined("IDC_TYPE")) define("IDC_TYPE", 1009);
if(!defined("IDC_VERBOSE")) define("IDC_VERBOSE", 1010);
if(!defined("IDC_STATIC1008")) define("IDC_STATIC1008", 1008);
if(!defined("IDC_NOTES")) define("IDC_NOTES", 1012);
if(!defined("IDC_GROUPBOX1014")) define("IDC_GROUPBOX1014", 1014);
if(!defined("IDC_CHM")) define("IDC_CHM", 1015);
if(!defined("IDC_COPYFILES")) define("IDC_COPYFILES", 1018);
if(!defined("IDC_EXPORTTODO")) define("IDC_EXPORTTODO", 1019);
if(!defined("IDC_CHECKDLLS")) define("IDC_CHECKDLLS", 1020);
if(!defined("IDC_TGZ")) define("IDC_TGZ", 1021);
if(!defined("IDC_ZIP")) define("IDC_ZIP", 1022);
if(!defined("IDC_RELNOTES")) define("IDC_RELNOTES", 1023);
if(!defined("IDC_GO")) define("IDC_GO", 1024);
if(!defined("IDC_ABOUT")) define("IDC_ABOUT", 1025);
if(!defined("IDC_SAVEINI")) define("IDC_SAVEINI", 1026);
if(!defined("IDC_GROUPBOX1027")) define("IDC_GROUPBOX1027", 1027);
if(!defined("IDC_STATIC1028")) define("IDC_STATIC1028", 1028);
if(!defined("IDC_STATIC1029")) define("IDC_STATIC1029", 1029);
if(!defined("IDC_MIME")) define("IDC_MIME", 1030);
if(!defined("IDC_FLIST")) define("IDC_FLIST", 1031);
if(!defined("IDC_XML")) define("IDC_XML", 1032);
if(!defined("IDC_STATIC1033")) define("IDC_STATIC1033", 1033);

// Create window

$mainwin = wb_create_window(NULL, PopupWindow, "Make releases", WBC_CENTER, WBC_CENTER, 561, 482, WBC_INVISIBLE, 0);

// Insert controls

wb_create_control($mainwin, Frame, "General Options", 10, 4, 262, 101, IDC_GROUPBOX1027, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Frame, "Build Options", 282, 4, 262, 227, IDC_GROUPBOX1014, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, EditBox, "(Output)", 10, 116, 262, 334, IDC_RESULT, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, Label, "Release &Number:", 19, 31, 92, 16, IDC_STATIC1008, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);
wb_create_control($mainwin, EditBox, "", 116, 27, 95, 21, IDC_VERSION, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "Release &Type:", 22, 60, 90, 16, IDC_STATIC1029, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);
wb_create_control($mainwin, ComboBox, "", 116, 55, 149, 98, IDC_TYPE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "&Verbose Output", 116, 80, 131, 21, IDC_VERBOSE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "Release notes:", 282, 237, 86, 16, IDC_STATIC1028, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, EditBox, "", 282, 259, 262, 155, IDC_NOTES, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, CheckBox, "Copy Additional &Files to Application Folder", 297, 21, 237, 21, IDC_COPYFILES, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Compile &CHM (HTML Help) Manual", 297, 41, 232, 21, IDC_CHM, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Export T&o Do List as an HTML file", 297, 60, 237, 21, IDC_EXPORTTODO, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Generate &Zip Archive", 297, 80, 125, 21, IDC_ZIP, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Check if WinBinder &DLLs are Up-to-Date", 321, 126, 217, 21, IDC_CHECKDLLS, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "From file list:", 312, 106, 70, 16, IDC_STATIC1033, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);
wb_create_control($mainwin, EditBox, "", 392, 103, 116, 19, IDC_FLIST, WBC_VISIBLE | WBC_ENABLED | WBC_READONLY);
wb_create_control($mainwin, CheckBox, "Create &XML Package Information (PECL)", 321, 145, 217, 21, IDC_XML, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Convert Zip to T&gz (PECL)", 321, 165, 197, 21, IDC_TGZ, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "&MIME Encode Zip file (for e-mail)", 321, 185, 191, 21, IDC_MIME, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Save &Release Notes", 297, 206, 152, 22, IDC_RELNOTES, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "Go", 282, 423, 77, 26, IDC_GO, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "&Save Config.", 374, 423, 77, 26, IDC_SAVEINI, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "&About...", 468, 423, 77, 26, IDC_ABOUT, WBC_VISIBLE | WBC_ENABLED);

// End controls

?>
